
const questions = [
  {
    type: "twoAnswers",
    name: "ageOver25",
    text: "Are you over age 25?",
    answers: [{
        label: "Yes",
        value: "true"
      },
      {
        label: "No",
        value: "false"
      }
    ]
  },
  {
    type: "input",
    name: "pizzas",
    text: "How many pizzas do you want?",
  }
]

function init() { 
  $(".follow, .icon img,.icon div, .avatar_mini, .all, .avatar, .round, #searchbar").click(function(){
    $("#popup").show();
  });

  const questionsDiv = $("#questions");
  const inputsDiv = $("#inputs");

  if (questions && questions.length > 0) {
    questionsDiv.show();

    for (const i in questions) {
      const question = questions[i];
  
      switch (question.type) {
        case "twoAnswers":
          questionsDiv.append(twoAnswersQuestion(question, parseInt(i)));
          break;
        case "input":
          questionsDiv.append(inputQuestion(question, parseInt(i)));
          break;
      }
    }

    // Button
    const okButton = $("<button/>");
    okButton.attr("id", "confirm");
    okButton.html("Next");
    okButton.click(function() {
      questionsDiv.hide();
      inputsDiv.show();
    });
    const buttonDiv = $("<div/>");
    buttonDiv.append(okButton);

    questionsDiv.append(buttonDiv);

  } else {
    inputsDiv.show();
  }
}

function twoAnswersQuestion(question, i) {

  const questionDiv = $("<div/>");
  questionDiv.prop("id", "q_" + i);

  // Input
  const input = $("<input/>");
  input.prop("name", "q_" + question.name);
  input.prop("type", "hidden");
  questionDiv.append(input);

  // Text
  const textDiv = $("<div/>");
  textDiv.html(question.text);
  textDiv.addClass("check_label");
  questionDiv.append(textDiv);

  // Answer
  const answerDiv = $("<div/>");
  answerDiv.addClass("check_buttons");

  const aButton = $("<button/>");
  aButton.addClass("yes_button");
  aButton.html(question.answers[0].label);
  aButton.click(function() {
    input.val(question.answers[0].value);
    aButton.addClass("selected_button");
    bButton.removeClass("selected_button");
  });
  answerDiv.append(aButton);

  const bButton = $("<button/>");
  bButton.addClass("no_button");
  bButton.html(question.answers[1].label);
  bButton.click(function() {
    input.val(question.answers[1].value);
    bButton.addClass("selected_button");
    aButton.removeClass("selected_button");
  });
  answerDiv.append(bButton);

  questionDiv.append(answerDiv);

  return questionDiv;
}

function inputQuestion(question, i) {

  const questionDiv = $("<div/>");
  questionDiv.prop("id", "q_" + i);

  // Answer
  const answerDiv = $("<div/>");

  // Input
  const input = $("<input/>");
  input.prop("name", "q_" + question.name);
  input.prop("type", "text");
  input.prop("placeholder", question.text);
  answerDiv.append(input);

  questionDiv.append(answerDiv);

  return questionDiv;
}

function submit() { 
  const name = $('[ng-model="name"]').val();
  const nameError = $('[data-error="name"]');

  const phone = $('[ng-model="phone"]').val();
  const phoneError = $('[data-error="phone"]');

  const email = $('[ng-model="email"]').val();
  const emailError = $('[data-error="email"]');

  const age = $('[ng-model="age"]').val();
  const ageError = $('[data-error="age"]');

  if(name === "") {
    nameError.html("Required");
    nameError.show();
  } else {
    nameError.hide();
  }

  if(phone === "") {
    phoneError.html("Required");
    phoneError.show();
  } else {
    phoneError.hide();
  }

  if(email === "") {
    emailError.html("Required");
    emailError.show();
  } else {
    emailError.hide();
  }

  if(age === "") {
    ageError.html("Required");
    ageError.show();
  } else {
    if (parseInt(age) < 18) {
      ageError.html("Not old enough");
      ageError.show();
    } else {
      ageError.hide();
    }
  }

  if (name !== "" && phone !== "" && email !== "" && (age !== "" && parseInt(age) >= 18)) {

    var answers = getAnswers();
    
    $("#popup").hide();
		$(".results").show();

    $.ajax({
      url: "api.php",
      dataType: "json",
      data: {
        "name": name,
        "phone": phone,
        "email": email,
        "answers": answers,
      },
      method: 'GET',
      success: function(data) {
        console.log(data);

        $(".results").hide();
      },
      error: function(data) {
        console.error(data.responseJSON);
      }
    });
  }

  return false;
}

function getAnswers() {
  var $inputs = $('[name^="q_"]');

  var values = {};
  $inputs.each(function() {
    values[this.name] = $(this).val();
  });

  var answers = {};
  for (const name in values) {
    if (name.includes("q_")) {
      const nameC = name.split("_")[1];
      answers[nameC] = values[name];
    }
  }

  return answers;
}

// When ready
$(document).ready(function() {
	init();
});